==> slimmer-1.0.0.tar.gz: slimmer/src/Service/LogService.php <==
<?php

namespace Drupal\slimmer\Service;

use GuzzleHttp\ClientInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Psr\Log\LoggerInterface;

class LogService implements LoggerInterface {

  use RfcLoggerTrait;


  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * Constructor.
   */
  public function __construct(ClientInterface $httpClient) {
    $this->httpClient = $httpClient;
  }

  /**
   * @param $level
   * @param $message
   *
   * @return array|false
   */
  private function createPostArray($level, $message) {
    $config = \Drupal::config('slimmer.settings');

    if (empty($config->get('slimmer_project'))) {
      return FALSE;
    }

    if (empty($level)) {
      return FALSE;
    }

    if (empty($message)) {
      return FALSE;
    }

    $post_array = [
      'project' => $config->get('slimmer_project'),
      'timestamp' => time(),
      'type' => 'error',
      'level' => (string) $level,
      'data' => [
        'message' => $message,
      ],
      'user' => \Drupal::currentUser()->id(),
      'location' => $_SERVER['REQUEST_URI'],
    ];

    return $post_array ?? [];
  }

  /**
   * @param $level
   * @param $message
   * @param array $context
   *
   * @return false|void
   */
  public function log($level, $message, array $context = []): void {
    $config = \Drupal::config('slimmer.settings');
    $post_array = $this->createPostArray($level, $message ?? $context['@message'] ?? '') ?? [];
    $allowed_levels = [];

    if (!$post_array) {
      return;
    }

    if (!intval($config->get('slimmer_autolog'))) {
      return;
    }

    foreach ($config->get('slimmer_level') as $key => $value) {
      if ($value !== 0) {
        $allowed_levels[] = intval($value);
      }
    }

    if (in_array($level, $allowed_levels)) {
      try {
        $this->httpClient->post($config->get('slimmer_endpoint'), [
          'headers' => [
            'Content-Type' => 'application/json',
          ],
          'body' => json_encode($post_array),
        ]);
      } catch (\Exception $e) {
        \Drupal::logger('slimmer')
          ->error('Cannot post log to dashboard from autologger');
      }
    }
  }

  /**
   * @param $level
   * @param $message
   *
   * @return false|void
   */
  public function slimmerLog($level, $message) {
    $config = \Drupal::config('slimmer.settings');

    $post_array = $this->createPostArray($level, $message) ?? FALSE;

    if (!$post_array) {
      return FALSE;
    }

    try {
      $this->httpClient->post($config->get('slimmer_endpoint'), [
        'headers' => [
          'Content-Type' => 'application/json',
        ],
        'body' => json_encode($post_array),
      ]);
    } catch (\Exception $e) {
      \Drupal::logger('slimmer')
        ->error('Cannot post log to dashboard from custom logger');
    }

  }

}

==> slimmer-1.0.1.tar.gz: slimmer/src/Service/LogService.php <==
<?php

namespace Drupal\slimmer\Service;

use GuzzleHttp\ClientInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Psr\Log\LoggerInterface;

class LogService implements LoggerInterface {

  use RfcLoggerTrait;


  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * Constructor.
   */
  public function __construct(ClientInterface $httpClient, LoggerInterface $logger) {
    $this->httpClient = $httpClient;
    $this->logger = $logger;
  }

  /**
   * Logs a message with the custom 'slimmer' log level.
   *
   * @param string $message
   *   The log message.
   */
  public function logSlimmerMessage(string $message) {
    $this->logger->log('slimmer', $message);
  }

  /**
   * @param $level
   * @param $message
   *
   * @return array|false
   */
  private function createPostArray($level, $message) {
    $config = \Drupal::config('slimmer.settings');

    if (empty($config->get('slimmer_project'))) {
      return FALSE;
    }

    if (empty($level)) {
      return FALSE;
    }

    if (empty($message)) {
      return FALSE;
    }

    $post_array = [
      'project' => $config->get('slimmer_project'),
      'timestamp' => time(),
      'type' => $this->getLevel($level) ?? 'error',
      'level' => (string) $level,
      'data' => [
        'message' => $message,
      ],
      'user' => \Drupal::currentUser()->id(),
      'location' => $_SERVER['REQUEST_URI'],
    ];

    return $post_array ?? [];
  }

  private function getLevel($level) {
    $mapping = [
      'emergency' => 0,
      'alert' => 1,
      'critical' => 2,
      'error' => 3,
      'warning' => 4,
      'notice' => 5,
      'info' => 6,
      'debug' => 7,
      'slimmer' => 8,
    ];

    return array_keys($mapping, $level)[0] ?? 'error';
  }

  /**
   * @param $level
   * @param $message
   * @param array $context
   *
   * @return false|void
   */
  public function log($level, $message, array $context = []): void {
    if ($context['channel'] == 'slimmer') {
      $config = \Drupal::config('slimmer.settings');
      $post_array = $this->createPostArray($level, $message ?? $context['@message'] ?? '') ?? [];

      $allowed_levels = [];

      if (!$post_array) {
        return;
      }

      if (!intval($config->get('slimmer_autolog'))) {
        return;
      }

      try {
        $this->httpClient->post($config->get('slimmer_endpoint'), [
          'headers' => [
            'Content-Type' => 'application/json',
          ],
          'body' => json_encode($post_array),
        ]);
      } catch (\Exception $e) {
        \Drupal::logger('slimmer')
          ->error('Cannot post log to dashboard from autologger');
      }
    }
  }

  /**
   * @param $level
   * @param $message
   *
   * @return false|void
   */
  public function slimmerLog($level, $message) {
    $config = \Drupal::config('slimmer.settings');

    $post_array = $this->createPostArray($level, $message) ?? FALSE;

    if (!$post_array) {
      return FALSE;
    }

    try {
      $this->httpClient->post($config->get('slimmer_endpoint'), [
        'headers' => [
          'Content-Type' => 'application/json',
        ],
        'body' => json_encode($post_array),
      ]);
    } catch (\Exception $e) {
      \Drupal::logger('slimmer')
        ->error('Cannot post log to dashboard from custom logger');
    }

  }

}
